# combo - content management system
# Copyright (C) 2014-2022  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf import settings
from django.forms.widgets import Select
from django.urls import reverse


class FlexSize(Select):
    template_name = 'combo/widgets/flexsize.html'


class PageSelect2Widget(Select):
    min_choices = 20

    class Media:
        js = 'xstatic/select2.min.js'
        css = {'all': ('xstatic/select2.min.css',)}

    def __init__(self, selected_page, *args, **kwargs):
        super().__init__(*args, **kwargs)

        if len(self.choices) > self.min_choices:
            current_choice = selected_page.id if selected_page else None
            self.choices = [x for x in self.choices if x[0] == current_choice]
            self.attrs['data-autocomplete'] = 'true'
            self.attrs['lang'] = settings.LANGUAGE_CODE
            self.attrs['data-select2-url'] = reverse('combo-manager-select2-page-choices')
